summaryrefslogtreecommitdiffstats
path: root/chrome/browser/plugin_installer.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-23 22:55:01 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-23 22:55:01 +0000
commit6e95706dcc9a205e78b1d4820427754d16a50465 (patch)
tree6bca69c386a5199bc88f59f0f92afc6dd6734fc3 /chrome/browser/plugin_installer.h
parent1ffdb40816d6a92cbcb7eb6c2386232c561abc56 (diff)
downloadchromium_src-6e95706dcc9a205e78b1d4820427754d16a50465.zip
chromium_src-6e95706dcc9a205e78b1d4820427754d16a50465.tar.gz
chromium_src-6e95706dcc9a205e78b1d4820427754d16a50465.tar.bz2
Move a bunch of functions from WebContents to TabContents. Change the services
used by the getters I moved to take a TabContents instead of a WebContents. Review URL: http://codereview.chromium.org/96010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@14362 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/plugin_installer.h')
-rw-r--r--chrome/browser/plugin_installer.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/plugin_installer.h b/chrome/browser/plugin_installer.h
index 642e643..8760c4f 100644
--- a/chrome/browser/plugin_installer.h
+++ b/chrome/browser/plugin_installer.h
@@ -7,13 +7,13 @@
#include "chrome/browser/tab_contents/infobar_delegate.h"
-class WebContents;
+class TabContents;
// The main purpose for this class is to popup/close the infobar when there is
// a missing plugin.
class PluginInstaller : public ConfirmInfoBarDelegate {
public:
- explicit PluginInstaller(WebContents* web_contents);
+ explicit PluginInstaller(TabContents* tab_contents);
~PluginInstaller();
void OnMissingPluginStatus(int status);
@@ -28,8 +28,8 @@ class PluginInstaller : public ConfirmInfoBarDelegate {
virtual std::wstring GetButtonLabel(InfoBarButton button) const;
virtual bool Accept();
- // The containing WebContents
- WebContents* web_contents_;
+ // The containing TabContents
+ TabContents* tab_contents_;
DISALLOW_COPY_AND_ASSIGN(PluginInstaller);
};